Documentation
¶
Index ¶
- func ConfigFromStruct(configStruct ConfigEnv, fnStore FunctionStore) configprovider.ConfigStore
- func ConfigFromYaml(yamlFiles []string, fnStore FunctionStore) configprovider.ConfigStore
- func NewPipewave(config PipewaveConfig) delivery.ModuleDelivery
- type ConfigEnv
- type FunctionStore
- type PipewaveConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigFromStruct ¶
func ConfigFromStruct(configStruct ConfigEnv, fnStore FunctionStore) configprovider.ConfigStore
func ConfigFromYaml ¶
func ConfigFromYaml(yamlFiles []string, fnStore FunctionStore) configprovider.ConfigStore
func NewPipewave ¶
func NewPipewave(config PipewaveConfig) delivery.ModuleDelivery
Types ¶
type ConfigEnv ¶
type ConfigEnv = configprovider.EnvType
type FunctionStore ¶
type FunctionStore = configprovider.Fns
type PipewaveConfig ¶
type PipewaveConfig struct {
ConfigStore configprovider.ConfigStore
RepositoryFactory repository.RepoFactory
QueueFactory queueprovider.QueueFactory
SlogIns *slog.Logger
}
Directories
¶
| Path | Synopsis |
|---|---|
|
core
|
|
|
gen
|
|
|
global
|
|
|
helper
|
|
|
pkg
|
|
|
provider
|
|
|
shared
|
|
|
aerror
Code generated by "gen-template-for-enum"; DO NOT EDIT.
|
Code generated by "gen-template-for-enum"; DO NOT EDIT. |
|
tools
|
|
|
gen-i18n
command
Stringer is a tool to automate the creation of methods that satisfy the fmt.Stringer interface.
|
Stringer is a tool to automate the creation of methods that satisfy the fmt.Stringer interface. |
|
gen-template-for-enum
command
|
|
|
wire-collect
command
|
Click to show internal directories.
Click to hide internal directories.